# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: watchdog/v1/watchdog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1awatchdog/v1/watchdog.proto\x12\x08watchdog\"\xb2\x01\n\x10\x43onfigurationSet\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x12\n\ntimeout_ms\x18\x02 \x01(\x07\x12\x1b\n\x13wd_reboot_threshold\x18\x03 \x01(\x07\x12\x18\n\x10wd_reboot_window\x18\x04 \x01(\x07\x12\x15\n\rwd_boot_delay\x18\x05 \x01(\x07\x12,\n\x08strategy\x18\x06 \x01(\x0e\x32\x1a.watchdog.WatchdogStrategy\"\x1a\n\x18\x43onfigurationSetResponse\"\x12\n\x10\x43onfigurationGet\"\x1a\n\x18\x43onfigurationGetResponse\"\x17\n\x15\x43onfigurationDescribe\"\x1f\n\x1d\x43onfigurationDescribeResponse\"\xc2\x01\n\x15\x43onfigurationResponse\x12\x31\n\x03get\x18\x01 \x01(\x0b\x32\".watchdog.ConfigurationGetResponseH\x00\x12\x31\n\x03set\x18\x02 \x01(\x0b\x32\".watchdog.ConfigurationSetResponseH\x00\x12;\n\x08\x64\x65scribe\x18\x03 \x01(\x0b\x32\'.watchdog.ConfigurationDescribeResponseH\x00\x42\x06\n\x04type\"\x14\n\x12\x46unctionControlGet\"\"\n\x12\x46unctionControlSet\x12\x0c\n\x04kick\x18\x01 \x01(\x08\"\x1c\n\x1a\x46unctionControlGetResponse\"\x16\n\x14SetPixelAreaResponse\"\x16\n\x14SetDisplayOnResponse\"\x1c\n\x1a\x46unctionControlSetResponse\"\x14\n\x12StreamControlStart\"\x0c\n\nStreamData*:\n\x10WatchdogStrategy\x12\x0c\n\x08POWERCUT\x10\x00\x12\x0c\n\x08SHUTDOWN\x10\x01\x12\n\n\x06REBOOT\x10\x02\x42\rZ\x0bwatchdog/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'watchdog.v1.watchdog_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\013watchdog/v1'
  _globals['_WATCHDOGSTRATEGY']._serialized_start=754
  _globals['_WATCHDOGSTRATEGY']._serialized_end=812
  _globals['_CONFIGURATIONSET']._serialized_start=41
  _globals['_CONFIGURATIONSET']._serialized_end=219
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_start=221
  _globals['_CONFIGURATIONSETRESPONSE']._serialized_end=247
  _globals['_CONFIGURATIONGET']._serialized_start=249
  _globals['_CONFIGURATIONGET']._serialized_end=267
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_start=269
  _globals['_CONFIGURATIONGETRESPONSE']._serialized_end=295
  _globals['_CONFIGURATIONDESCRIBE']._serialized_start=297
  _globals['_CONFIGURATIONDESCRIBE']._serialized_end=320
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_start=322
  _globals['_CONFIGURATIONDESCRIBERESPONSE']._serialized_end=353
  _globals['_CONFIGURATIONRESPONSE']._serialized_start=356
  _globals['_CONFIGURATIONRESPONSE']._serialized_end=550
  _globals['_FUNCTIONCONTROLGET']._serialized_start=552
  _globals['_FUNCTIONCONTROLGET']._serialized_end=572
  _globals['_FUNCTIONCONTROLSET']._serialized_start=574
  _globals['_FUNCTIONCONTROLSET']._serialized_end=608
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_start=610
  _globals['_FUNCTIONCONTROLGETRESPONSE']._serialized_end=638
  _globals['_SETPIXELAREARESPONSE']._serialized_start=640
  _globals['_SETPIXELAREARESPONSE']._serialized_end=662
  _globals['_SETDISPLAYONRESPONSE']._serialized_start=664
  _globals['_SETDISPLAYONRESPONSE']._serialized_end=686
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_start=688
  _globals['_FUNCTIONCONTROLSETRESPONSE']._serialized_end=716
  _globals['_STREAMCONTROLSTART']._serialized_start=718
  _globals['_STREAMCONTROLSTART']._serialized_end=738
  _globals['_STREAMDATA']._serialized_start=740
  _globals['_STREAMDATA']._serialized_end=752
# @@protoc_insertion_point(module_scope)
